pub trait Distance {
// Required method
fn distance(&self, n: &ImageNodeColor, m: &ImageNodeColor) -> f32;
}Expand description
Trait to be implemented by a concrete distance. The distance defines how the weights between nodes in the image graph are computed. See the paper by Felzenswalb and Huttenlocher for details.
Required Methods
Sourcefn distance(&self, n: &ImageNodeColor, m: &ImageNodeColor) -> f32
fn distance(&self, n: &ImageNodeColor, m: &ImageNodeColor) -> f32
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".