pub trait NodeMerging {
// Required method
fn should_merge(
&self,
s_n: &Cell<ImageNode>,
s_m: &Cell<ImageNode>,
e: &ImageEdge,
) -> bool;
}Expand description
The magic part of the graph segmentation, i.e. s given two nodes decide whether to add an edge between them (i.e. merge the corresponding segments). See the paper by Felzenswalb and Huttenlocher for details.
Required Methods
Sourcefn should_merge(
&self,
s_n: &Cell<ImageNode>,
s_m: &Cell<ImageNode>,
e: &ImageEdge,
) -> bool
fn should_merge( &self, s_n: &Cell<ImageNode>, s_m: &Cell<ImageNode>, e: &ImageEdge, ) -> bool
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".